@@ -108,6 +108,13 @@ class AbstractTodo(Comparable, Protocol):
     def done(self) -> bool:  # noqa: D102
         """Is this todo marked done with an 'x'?"""
 
+    @property
+    def epics(self) -> Tuple[str, ...]:  # noqa: D102
+        """A todo's epics.
+
+        A word is normally marked as an epic by prefixing it with '#'.
+        """
+
     @property
     def metadata(self) -> Metadata:  # noqa: D102
         """A todo's corresponding metadata dictionary.
